
#if defined(ESP32)
#include <WiFi.h>
#elif defined(ESP8266)
#include <ESP8266WiFi.h>
#endif
#include <ESP_Mail_Client.h>

#include "DHT.h"
#define DHTPIN D1                                     // DHT11 подключен к D1  
#define DHTTYPE DHT11                                 // Тип датчика DHT    
DHT dht(DHTPIN, DHTTYPE);  
float t;
int h;

unsigned long send_time;                              // Переменная для хранения времени отправки сообщения(через сколько следующее)

#define WIFI_SSID "XXXXXX"                            // Название WIFI сети
#define WIFI_PASSWORD "XXXXXXXX"                      // Пароль WIFI сети

#define SMTP_HOST "smtp.gmail.com"                    // SMTP сервер smtp.gmail.com   smtp.yandex.ru    smtp.mail.ru
#define SMTP_PORT 465

// Учетные данные для входа (адрес электронной почты и пароль, используемые для отправки сообщений)
#define AUTHOR_EMAIL "XXXXXXX@gmail.com"  
#define AUTHOR_PASSWORD "XXXXXXXXXXX"

SMTPSession smtp;                                   // Объект SMTP

#define ON_Board_LED 2                              //  GPIO2(D4). Светодиод на плате

void setup() {  
  Serial.begin(115200);
  dht.begin();
  Serial.println();
  pinMode(ON_Board_LED,OUTPUT);                     // Светодиод на плате определяем как выход
  digitalWrite(ON_Board_LED, HIGH);                 // Выключаем светодиод

// Подключение esp8266 к Wi-Fi-маршрутизатору или точке доступа
  Serial.print("Connecting to AP");

  WiFi.begin(WIFI_SSID, WIFI_PASSWORD);
  while (WiFi.status() != WL_CONNECTED)
  {
    Serial.print(".");
// Светодиод мигает при подключении к Wi-Fi-маршрутизатору
    digitalWrite(ON_Board_LED, LOW);
    delay(250);
    digitalWrite(ON_Board_LED, HIGH);
    delay(250);
  }

  digitalWrite(ON_Board_LED, HIGH);                   // Выключаем светодиод

  Serial.println("");
  Serial.println("WiFi соединение.");
  Serial.println("IP адрес: ");
  Serial.println(WiFi.localIP());
  Serial.println();
} 
   

void loop() {
  t = dht.readTemperature();
  h = dht.readHumidity();
  
  if (isnan(h) || isnan(t)) {
    Serial.println("Ошибка DHT датчика!");
    delay(500);
    return;
  }

  smtp.debug(0);                                     // Отладочная информация 0 - выкл      1 - вкл
  smtp.callback(smtpCallback);                       // ФункциЯ обратного вызова для получения результатов отправки 
  ESP_Mail_Session session;
  
 // Конфигурация сеанса
  session.server.host_name = SMTP_HOST;
  session.server.port = SMTP_PORT;
  session.login.email = AUTHOR_EMAIL;
  session.login.password = AUTHOR_PASSWORD;

  SMTP_Message message;                               // Класс сообщения

 // Устанавливаем заголовок сообщения
  message.sender.name = "DHT11-ESP";                              // ЗАГОЛОВОК 
  message.sender.email = AUTHOR_EMAIL;
  message.subject = "Тревога. Превышена температура";             // Тело письма
  message.addRecipient("DHT11-ESP", "XXXXXXXX@gmail.com");    // Заголовок и адрес получателя можно указать любую почту на других серверах

  // Сообщение письма
  String textMsg;
  textMsg = "Температура превышена\n Это сообщение отправлено с ОХРАНЯЕМОГО ОБЪЕКТА, при помощи ESP8266\nТемпература = " + String(t)+"°C";
   message.text.content = textMsg.c_str();
  message.text.charSet = "utf-8"; 
  message.text.transfer_encoding = Content_Transfer_Encoding::enc_7bit;
  message.priority = esp_mail_smtp_priority::esp_mail_smtp_priority_high; 
  message.response.notify = esp_mail_smtp_notify_success | esp_mail_smtp_notify_failure | esp_mail_smtp_notify_delay;
 
      if (!smtp.connect(&session)) return;                    // Подключение к серверу с конфигурацией сеанса
  Serial.print("температура - ");
  Serial.print(t);
  Serial.println("°C");
 
// Отправка сообщения если температура больше 30С
  if(t >= 30) {
    if(millis() - send_time > 60000) {                         // 1 минута = 60000
        if (!MailClient.sendMail(&smtp, &message)) Serial.println("Ошибка отправки сообщения, " + smtp.errorReason());
      Serial.print("температура - ");
      Serial.print(t);
      Serial.println("°C");
      send_time = millis();
    }
  }
  delay(3000);
}

// Функция обратного вызова для получения статуса отправки электронной почты
void smtpCallback(SMTP_Status status) {
  //Serial.println(status.info());                          // Печать статуса

// Печать результата отправки сообщения
  if (status.success()) {
    Serial.println("----------------");
    Serial.printf("Сообщение отправлено успешно: %d\n", status.completedCount());
    Serial.printf("Сообщение отправить не удалось: %d\n", status.failedCount());
    Serial.println("----------------\n");
    struct tm dt;
    
    for (size_t i = 0; i < smtp.sendingResult.size(); i++) {
      SMTP_Result result = smtp.sendingResult.getItem(i);
      Serial.printf("Сообщение №: %d\n", i + 1);
      Serial.printf("Статус: %s\n", result.completed ? "Успешно" : "Ошибка");
      Serial.printf("Дата/Время: %d/%d/%d %d:%d:%d\n", dt.tm_year + 1900, dt.tm_mon + 1, dt.tm_mday, dt.tm_hour, dt.tm_min, dt.tm_sec);
      Serial.printf("Получатель: %s\n", result.recipients);
      Serial.printf("Тема: %s\n", result.subject);
    }
    Serial.println("----------------\n");
  }
}
